@@ -1,6 +1,7 @@
 #
 # -*- coding: iso-8859-1 -*-
 #
+# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -48,6 +49,9 @@ class PokerAvatar:
         self.bugous_processing_hand = False
         self.noqueuePackets()
 
+    def __str__(self):
+        print "PokerAvatar serial = %s, name = %s" % ( self.getSerial(), self.getName() )
+
     def setProtocol(self, protocol):
         self.protocol = protocol
 
@@ -169,7 +173,7 @@ class PokerAvatar:
     
     def sendPacketVerbose(self, packet):
         if self.service.verbose > 1 and hasattr(packet, 'type') and packet.type != PACKET_PING or self.service.verbose > 5:
-            print "PokerAvatar::sendPacket: %s" % str(packet)
+            print "PokerAvatar::sendPacket(%d): %s" % ( self.getSerial(), str(packet) )
         self.sendPacket(packet)
         
     def packet2table(self, packet):
@@ -185,7 +189,7 @@ class PokerAvatar:
         return self.resetPacketsQueue()
         
     def handlePacketLogic(self, packet):
-        if self.service.verbose > 2 and packet.type != PACKET_PING: print "PokerAvatar::handleConnection: " + str(packet)
+        if self.service.verbose > 2 and packet.type != PACKET_PING: print "PokerAvatar::handleConnection(%d): " % self.getSerial() + str(packet)
         
         if not self.isAuthorized(packet.type):
             self.sendPacketVerbose(PacketAuthRequest())
@@ -202,6 +206,10 @@ class PokerAvatar:
             self.sendPacketVerbose(self.getPlayerInfo())
             return
 
+        if packet.type == PACKET_POKER_GET_PLAYER_IMAGE:
+            self.sendPacketVerbose(self.service.getPlayerImage(packet.serial))
+            return
+
         if packet.type == PACKET_POKER_GET_USER_INFO:
             if self.getSerial() == packet.serial:
                 self.getUserInfo(packet.serial)
@@ -229,6 +237,18 @@ class PokerAvatar:
                 print "attempt to set player info for player %d by player %d" % ( packet.serial, self.getSerial() )
             return
                 
+        elif packet.type == PACKET_POKER_PLAYER_IMAGE:
+            if self.getSerial() == packet.serial:
+                if self.service.setPlayerImage(packet):
+                    self.sendPacketVerbose(PacketAck())
+                else:
+                    self.sendPacketVerbose(PacketError(other_type = PACKET_POKER_PLAYER_IMAGE,
+                                                       code = PACKET_POKER_PLAYER_IMAGE,
+                                                       message = "Failed to save set player image"))
+            else:
+                print "attempt to set player info for player %d by player %d" % ( packet.serial, self.getSerial() )
+            return
+                
         elif packet.type == PACKET_POKER_PERSONAL_INFO:
             if self.getSerial() == packet.serial:
                 self.setPersonalInfo(packet)
