@@ -1,5 +1,6 @@
 # -*- py-indent-offset: 4; coding: iso-8859-1; mode: python -*-
 #
+# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -41,7 +42,7 @@ from pokerengine.pokerchips import PokerChips
 from pokerengine.pokerengineconfig import Config
 from pokernetwork.client import UGAMEClientProtocol, UGAMEClientFactory
 from pokernetwork.pokerchildren import PokerChildren, PokerChildBrowser
-from pokernetwork.pokerpackets import *
+from pokernetwork.pokerclientpackets import *
 from pokernetwork import upgrade
 
 DEFAULT_PLAYER_USER_DATA = { 'delay': 0, 'timeout': None }
@@ -114,6 +115,7 @@ class PokerClientFactory(UGAMEClientFactory):
         # so that the caller does not have to check the existence of the
         # attribute when catching an exception.
         #
+        self.crashing = False
         self.interface = None
         self.display = None
         self.children = None
@@ -254,6 +256,7 @@ class PokerClientFactory(UGAMEClientFactory):
 
     def isOutbound(self, packet):
         return ( packet.type == PACKET_ERROR or
+                 packet.type == PACKET_MESSAGE or
                  packet.type == PACKET_POKER_HAND_LIST or
                  packet.type == PACKET_POKER_PLAYER_INFO or
                  packet.type == PACKET_POKER_USER_INFO or
@@ -896,13 +899,22 @@ class PokerClientProtocol(UGAMEClientProtocol):
 
             elif packet.type == PACKET_POKER_REBUY:
                 forward_packets.remove(packet)
-                game.rebuy(packet.serial, packet.amount)
-                player = game.getPlayer(packet.serial)
-                chips = PacketPokerPlayerChips(game_id = game.id,
-                                               serial = packet.serial,
-                                               money = player.money,
-                                               bet = player.bet)
-                forward_packets.append(chips)
+                if game.rebuy(packet.serial, packet.amount):
+                    #
+                    # If the server says the player rebuys, assume he knows
+                    # that the player can rightfully do so and therefore
+                    # that the buy_in has already been paid. The client fail
+                    # to notice that a player already paid the buy_in 
+                    # when it connects to a table on which said player has
+                    # no chips in front of him.
+                    #
+                    game.buy_in_payed = True
+                    player = game.getPlayer(packet.serial)
+                    chips = PacketPokerPlayerChips(game_id = game.id,
+                                                   serial = packet.serial,
+                                                   money = player.money,
+                                                   bet = player.bet)
+                    forward_packets.append(chips)
 
             elif packet.type == PACKET_POKER_PLAYER_CHIPS:
                 player = game.getPlayer(packet.serial)
@@ -956,7 +968,7 @@ class PokerClientProtocol(UGAMEClientProtocol):
                 if game.isBlindAnteRound():
                     game.blindAnteRoundEnd()
 
-                if packet.string == "end":
+                if packet.string == "end" and game.state != "null":
                     game.endState()
 
                 #
@@ -1194,6 +1206,9 @@ class PokerClientProtocol(UGAMEClientProtocol):
         return packets
 
     def connectionLost(self, reason):
+        if self.factory.crashing:
+            print "connectionLost: crashing, just return."
+            return
         if self.factory.verbose:
             print "connectionLost: noticed, aborting all tables."
         self.abortAllTables()
@@ -1362,6 +1377,9 @@ class PokerClientProtocol(UGAMEClientProtocol):
                  not match("^Dealer:", packet.message) ):
                 return True
 
+            elif packet.type == PACKET_POKER_MESSAGE:
+                return True
+
             elif ( packet.type == PACKET_POKER_PLAYER_ARRIVE and
                    packet.serial == self.getSerial() ):
                 return True
@@ -1466,7 +1484,7 @@ class PokerClientProtocol(UGAMEClientProtocol):
         else:
             what = 'outbound'
 
-        if self.factory.verbose > 2: self.message("publishPacket: %s: %s" % ( what, packet ) )
+        if self.factory.verbose > 2: self.message("publishPacket(%d): %s: %s" % ( self.getSerial(), what, packet ) )
         if self.callbacks[what].has_key(packet.type):
             callbacks = self.callbacks[what][packet.type]
             for callback in callbacks:
