@@ -1,6 +1,7 @@
 #
 # -*- py-indent-offset: 4; coding: iso-8859-1 -*-
 #
+# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -74,6 +75,7 @@ except ImportError:
 from twisted.python import components
 
 from pokerengine.pokertournament import *
+from pokerengine.pokercards import PokerCards
 
 from pokernetwork.server import PokerServerProtocol
 from pokernetwork.user import checkName, checkPassword
@@ -132,6 +134,7 @@ class PokerService(service.Service):
     def __init__(self, settings):
         self.settings = settings
         self.verbose = self.settings.headerGetInt("/server/@verbose")
+        self.delays = settings.headerGetProperties("/server/delays")[0]
         self.db = None
         self.cashier = None
         self.poker_auth = None
@@ -141,25 +144,27 @@ class PokerService(service.Service):
 
     def startService(self):
         self.db = PokerDatabase(self.settings)
+        self.cleanupCrashedTables()
         self.cleanUp(temporary_users = self.settings.headerGet("/server/users/@temporary"))
         self.cashier = pokercashier.PokerCashier(self.settings)
         self.cashier.setDb(self.db)
         self.poker_auth = PokerAuth(self.db, self.settings)
         self.dirs = split(self.settings.headerGet("/server/path"))
         self.serial2client = {}
+        self.avatars = []
         self.tables = []
         self.table_serial = 100
         self.shutting_down = False
         self.simultaneous = self.settings.headerGetInt("/server/@simultaneous")
         self._ping_delay = self.settings.headerGetInt("/server/@ping")
         self.chat = self.settings.headerGet("/server/@chat") == "yes"
-        self.cleanupCrashedTables()
         for description in self.settings.headerGetProperties("/server/table"):
             self.createTable(0, description)
         self.tourneys = {}
         self.schedule2tourneys = {}
         self.tourneys_schedule = {}
         self.updateTourneysSchedule()
+        self.messageCheck()
         self.poker_auth.SetLevel(PACKET_POKER_SEAT, User.REGULAR)
         self.poker_auth.SetLevel(PACKET_POKER_GET_USER_INFO, User.REGULAR)
         self.poker_auth.SetLevel(PACKET_POKER_GET_PERSONAL_INFO, User.REGULAR)
@@ -177,6 +182,7 @@ class PokerService(service.Service):
 
     def stopService(self):
         deferred = self.shutdown()
+        deferred.addCallback(lambda x: reactor.disconnectAll())
         deferred.addCallback(self.stopServiceFinish)
         return deferred
 
@@ -192,8 +198,9 @@ class PokerService(service.Service):
         self.shutting_down = True
         self.cancelTimer('checkTourney')
         self.cancelTimer('updateTourney')
+        self.cancelTimer('messages')
         self.shutdown_deferred = defer.Deferred()
-        reactor.callLater(0, self.shutdownCheck)
+        reactor.callLater(0.01, self.shutdownCheck)
         return self.shutdown_deferred
 
     def shutdownCheck(self):
@@ -213,6 +220,7 @@ class PokerService(service.Service):
                 print "Shutdown immediately"
             self.down = True
             self.shutdown_deferred.callback(True)
+            self.shutdown_deferred = False
         else:
             reactor.callLater(10, self.shutdownCheck)
 
@@ -223,9 +231,15 @@ class PokerService(service.Service):
         pass
 
     def createAvatar(self):
-        return pokeravatar.PokerAvatar(self)
+        avatar = pokeravatar.PokerAvatar(self)
+        self.avatars.append(avatar)
+        return avatar
 
     def destroyAvatar(self, avatar):
+        if avatar in self.avatars:
+            self.avatars.remove(avatar)
+        else:
+            print "*ERROR* PokerService: avatar %s is not in the list of known avatars" % str(avatar)
         avatar.connectionLost("Disconnected")
 
     def sessionStart(self, serial, ip):
@@ -741,8 +755,6 @@ class PokerService(service.Service):
 
     def cleanUp(self, temporary_users = ''):
         cursor = self.db.cursor()
-        sql = "delete from user2table"
-        cursor.execute(sql)
 
         if len(temporary_users) > 2:
             sql = "delete session_history from session_history, users where session_history.user_serial = users.serial and users.name like '" + temporary_users + "%'"
@@ -777,6 +789,24 @@ class PokerService(service.Service):
         cursor.close()
         return money
 
+    def cashIn(self, packet):
+        return self.cashier.cashIn(packet)
+
+    def cashOut(self, packet):
+        return self.cashier.cashOut(packet)
+
+    def cashQuery(self, packet):
+        return self.cashier.cashQuery(packet)
+
+    def cashOutCommit(self, packet):
+        count = self.cashier.cashOutCommit(packet)
+        if count in (0, 1):
+            return PacketAck()
+        else:
+            return PacketError(code = PacketPokerCashOutCommit.INVALID_TRANSACTION,
+                               message = "transaction " + packet.transaction_id + " affected " + str(count) + " rows instead of zero or one",
+                               other_type = PACKET_POKER_CASH_OUT_COMMIT)
+
     def getPlayerInfo(self, serial):
         placeholder = PacketPokerPlayerInfo(serial = serial,
                                             name = "anonymous",
@@ -800,24 +830,6 @@ class PokerService(service.Service):
                                      url = skin_url,
                                      outfit = skin_outfit)
 
-    def cashIn(self, packet):
-        return self.cashier.cashIn(packet)
-
-    def cashOut(self, packet):
-        return self.cashier.cashOut(packet)
-
-    def cashQuery(self, packet):
-        return self.cashier.cashQuery(packet)
-
-    def cashOutCommit(self, packet):
-        count = self.cashier.cashOutCommit(packet)
-        if count in (0, 1):
-            return PacketAck()
-        else:
-            return PacketError(code = PacketPokerCashOutCommit.INVALID_TRANSACTION,
-                               message = "transaction " + packet.transaction_id + " affected " + str(count) + " rows instead of zero or one",
-                               other_type = PACKET_POKER_CASH_OUT_COMMIT)
-
     def getUserInfo(self, serial):
         cursor = self.db.cursor(DictCursor)
 
@@ -1006,6 +1018,40 @@ class PokerService(service.Service):
         return True
 
 
+    def getPlayerImage(self, serial):
+        placeholder = PacketPokerPlayerImage(serial = serial)
+
+        if serial == 0:
+            return placeholder
+
+        cursor = self.db.cursor()
+        sql = ( "select skin_image,skin_image_type from users where serial = " + str(serial) )
+        cursor.execute(sql)
+        if cursor.rowcount != 1:
+            print " *ERROR* getPlayerImage(%d) expected one row got %d" % ( serial, cursor.rowcount )
+            return placeholder
+        (skin_image, skin_image_type) = cursor.fetchone()
+        if skin_image == None:
+            skin_image = ""
+        cursor.close()
+        return PacketPokerPlayerImage(serial = serial,
+                                      image = skin_image,
+                                      image_type = skin_image_type)
+
+    def setPlayerImage(self, player_image):
+        cursor = self.db.cursor()
+        sql = ( "update users set "
+                " skin_image = '" + player_image.image + "', "
+                " skin_image_type = '" + player_image.image_type + "' "
+                " where serial = " + str(player_image.serial) )
+        if self.verbose > 1:
+            print "setPlayerInfo: %s" % sql
+        cursor.execute(sql)
+        if cursor.rowcount != 1 and cursor.rowcount != 0:
+            print " *ERROR* setPlayerImage: modified %d rows (expected 1 or 0): %s " % ( cursor.rowcount, sql )
+            return False
+        return True
+
     def getName(self, serial):
         if serial == 0:
             return "anonymous"
@@ -1098,7 +1144,7 @@ class PokerService(service.Service):
         cursor = self.db.cursor()
         if currency_serial != '':
            sql = ( "UPDATE user2money,user2table,pokertables SET " +
-                   " user2money.amount = user2money.amount + user2table.money " +
+                   " user2money.amount = user2money.amount + user2table.money + user2table.bet " +
                    " WHERE user2money.user_serial = user2table.user_serial AND " +
                    "       user2money.currency_serial = pokertables.currency_serial AND " +
                    "       pokertables.serial = " + str(table_id) + " AND " +
@@ -1301,11 +1347,13 @@ class PokerService(service.Service):
     def cleanupCrashedTables(self):
         cursor = self.db.cursor()
 
-        sql = ( "select user_serial,table_serial from user2table " )
+        sql = ( "select user_serial,table_serial,currency_serial from pokertables,user2table where user2table.table_serial = pokertables.serial " )
         cursor.execute(sql)
+        if cursor.rowcount > 0 and self.verbose > 1:
+            print "cleanupCrashedTables found %d players" % cursor.rowcount
         for i in xrange(cursor.rowcount):
-            (user_serial, table_serial) = cursor.fetchone()
-            self.leavePlayer(user_serial, table_serial)
+            (user_serial, table_serial, currency_serial) = cursor.fetchone()
+            self.leavePlayer(user_serial, table_serial, currency_serial)
 
         cursor.close()
         self.shutdownTables()
@@ -1331,6 +1379,26 @@ class PokerService(service.Service):
             print " *ERROR* deleted %d rows (expected 1): %s " % ( cursor.rowcount, sql )
         cursor.close()
 
+    def broadcast(self, packet):
+        for avatar in self.avatars:
+            if hasattr(avatar, "protocol") and avatar.protocol:
+                avatar.sendPacketVerbose(packet)
+            else:
+                print "broadcast: avatar %s excluded" % str(avatar)
+
+    def messageCheck(self):
+        cursor = self.db.cursor()
+        cursor.execute("SELECT serial,message FROM messages WHERE " + 
+                       "       sent = 'n' AND send_date < CURRENT_TIMESTAMP()")
+        rows = cursor.fetchall()
+        for (serial, message) in rows:
+            self.broadcast(PacketMessage(string = message))
+            cursor.execute("UPDATE messages SET sent = 'y' WHERE serial = %d" % serial)
+        cursor.close()
+        self.cancelTimer('messages')
+        delay = int(self.delays.get('messages', 60))
+        self.timer['messages'] = reactor.callLater(delay, self.messageCheck)
+
 class PokerAuth:
 
     def __init__(self, db, settings):
