@@ -1,6 +1,7 @@
 #
 # -*- coding: iso-8859-1 -*-
 #
+# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -72,7 +73,7 @@ class PokerTable:
         game.setMaxPlayers(int(description["seats"]))
         self.skin = description.get("skin", "default")
         self.currency_serial = int(description.get("currency_serial", 0))
-        self.playerTimeout = int(description["player_timeout"])        
+        self.playerTimeout = int(description.get("player_timeout", 60))
         self.muckTimeout = int(description.get("muck_timeout", 5))
         self.transient = description.has_key("transient")
         self.tourney = description.get("tourney", None)
@@ -132,13 +133,15 @@ class PokerTable:
     def createCache(self):
         return { "board": PokerCards(), "pockets": {} }
     
-    def beginTurn(self):
+    def cancelDealTimeout(self):
         info = self.timer_info
         if info.has_key("dealTimeout"):
             if info["dealTimeout"].active():
                 info["dealTimeout"].cancel()
             del info["dealTimeout"]
 
+    def beginTurn(self):
+        self.cancelDealTimeout()
         if not self.isRunning():
             self.historyReset()
             hand_serial = self.factory.getHandSerial()
@@ -203,9 +206,10 @@ class PokerTable:
             packets = ( packets, )
             
         for packet in packets:
+            keys = game.serial2player.keys()
             if self.factory.verbose > 1:
-                print "broadcast %s " % packet
-            for serial in game.serial2player.keys():
+                print "broadcast%s %s " % ( keys, packet )
+            for serial in keys:
                 #
                 # Player may be in game but disconnected.
                 #
@@ -406,6 +410,9 @@ class PokerTable:
             elif type == "wait_for":
                 pass
             
+            elif type == "rebuy":
+                pass
+            
             elif type == "player_list":
                 pass
             
@@ -586,6 +593,9 @@ class PokerTable:
             elif type == "finish":
                 pass
             
+            elif type == "rebuy":
+                pass
+            
             else:
                 print "compressedHistory: *ERROR* unknown history type %s " % type
 
@@ -635,6 +645,7 @@ class PokerTable:
                 self.factory.tourneyEndTurn(self.tourney, game.id)
         
     def autoDeal(self):
+        self.cancelDealTimeout()
         if not self.allReadyToPlay():
             #
             # All clients that fail to send a PokerReadyToPlay packet
@@ -652,10 +663,37 @@ class PokerTable:
         self.beginTurn()
         self.update()
         
+    def autoDealCheck(self, autodeal_check, delta):
+        if self.factory.verbose > 2:
+            print "autoDealCheck"
+        self.cancelDealTimeout()
+        if autodeal_check > delta:
+            if self.factory.verbose > 2:
+                print "Autodeal for %d scheduled in %f seconds" % ( self.game.id, delta )
+            self.timer_info["dealTimeout"] = reactor.callLater(delta, self.autoDeal)
+            return
+        game = self.game
+        #
+        # Issue a poker message to all players that are ready
+        # to play.
+        #
+        serials = []
+        for player in game.playersAll():
+            if ( player.getUserData()['ready'] == True and
+                 self.serial2client.has_key(player.serial) ):
+                serials.append(player.serial)
+        if serials:
+            packet = PacketPokerMessage(game_id = self.game.id,
+                                        string = "Waiting for players.\nNext hand will be dealt shortly.\n(maximum %d seconds)" % int(delta))
+            for serial in serials:
+                client = self.serial2client[serial]
+                client.sendPacket(packet)
+        if self.factory.verbose > 2:
+            print "AutodealCheck(2) for %d scheduled in %f seconds" % ( self.game.id, delta )
+        self.timer_info["dealTimeout"] = reactor.callLater(autodeal_check, self.autoDealCheck, autodeal_check, delta - autodeal_check)
+
     def scheduleAutoDeal(self):
-        info = self.timer_info
-        if info.has_key("dealTimeout") and info["dealTimeout"].active():
-            info["dealTimeout"].cancel()
+        self.cancelDealTimeout()
         if self.factory.shutting_down:
             if self.factory.verbose > 2:
                 print "Not autodealing because server is shutting down"
@@ -692,11 +730,14 @@ class PokerTable:
         if not self.allReadyToPlay() and delay > 0:
             delta = ( self.game_delay["start"] + delay ) - time.time()
             if delta < 0: delta = 0
+            autodeal_max = float(self.delays.get("autodeal_max", 120))
+            if delta > autodeal_max: delta = autodeal_max
         else:
             delta = 0
         if self.factory.verbose > 2:
-            print "Autodeal scheduled in %f seconds" % delta
-        info["dealTimeout"] = reactor.callLater(delta, self.autoDeal)
+            print "AutodealCheck scheduled in %f seconds" % delta
+        autodeal_check = max(0.01, float(self.delays.get("autodeal_check", 15)))
+        self.timer_info["dealTimeout"] = reactor.callLater(min(autodeal_check, delta), self.autoDealCheck, autodeal_check, delta)
 
     def updatePlayerUserData(self, serial, key, value):
         game = self.game
@@ -1059,6 +1100,10 @@ class PokerTable:
             client.error("table refuses to seat player %d" % serial)
             return False
 
+        if seat != -1 and seat not in game.seats_left:
+            client.error("table refuses to seat player %d at seat %d" % ( serial, seat ))
+            return False
+
         amount = 0
         if self.transient:
             amount = game.buyIn()
