@@ -1,4 +1,5 @@
 #
+# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -29,6 +30,7 @@ import sys
 from twisted.internet import reactor, protocol, defer
 
 from pokernetwork.protocol import UGAMEProtocol
+from pokernetwork.packets import PacketError
 
 class PokerServerProtocol(UGAMEProtocol):
     """UGAMEServerProtocol"""
@@ -71,6 +73,7 @@ class PokerServerProtocol(UGAMEProtocol):
             packet = packets.pop(0)
             if isinstance(packet, defer.Deferred):
                 packet.addCallback(self.unshiftPacket, packets)
+                packet.addErrback(self.deferredError, packets)
                 #
                 # No packet may be received while sending the answer to
                 # a previous packet.
@@ -80,6 +83,11 @@ class PokerServerProtocol(UGAMEProtocol):
             else:
                 self.sendPacket(packet)
 
+    def deferredError(self, reason, packets):
+        packet = PacketError(message = str(reason))
+        packets.insert(0, packet)
+        self.sendPackets(packets)
+
     def unshiftPacket(self, packet, packets):
         packets.insert(0, packet)
         self.sendPackets(packets)
